@@ -58,7 +58,6 @@ using clang::CXXMethodDecl;
 using clang::CXXNewExpr;
 using clang::CXXRecordDecl;
 using clang::CallExpr;
-using clang::CastExpr;
 using clang::ClassTemplateDecl;
 using clang::ClassTemplatePartialSpecializationDecl;
 using clang::ClassTemplateSpecializationDecl;
@@ -72,7 +71,6 @@ using clang::DependentTemplateName;
 using clang::DependentTemplateSpecializationType;
 using clang::ElaboratedType;
 using clang::EnumDecl;
-using clang::ExplicitCastExpr;
 using clang::Expr;
 using clang::ExprWithCleanups;
 using clang::FileEntry;
@@ -428,10 +426,7 @@ string PrintableLoc(SourceLocation loc) {
   if (loc.isInvalid()) {
     return "Invalid location";
   } else {
-    std::string buffer;  // llvm wants regular string, not our versa-string
-    raw_string_ostream ostream(buffer);
-    loc.print(ostream, *GlobalSourceManager());
-    return NormalizeFilePath(ostream.str());
+    return NormalizeFilePath(loc.printToString(*GlobalSourceManager()));
   }
 }
 
@@ -1100,11 +1095,14 @@ bool DeclsAreInSameClass(const Decl* decl1, const Decl* decl2) {
   return decl1->getDeclContext()->isRecord();
 }
 
-bool IsBuiltinFunction(const clang::NamedDecl* decl,
-                       const std::string& symbol_name) {
+bool IsBuiltinFunction(const clang::NamedDecl* decl) {
   if (const clang::IdentifierInfo* iden = decl->getIdentifier()) {
-    return iden->getBuiltinID() != 0 &&
-           !clang::Builtin::Context::isBuiltinFunc(symbol_name.c_str());
+    unsigned builtin_id = iden->getBuiltinID();
+    if (builtin_id != 0) {
+      const clang::Builtin::Context& ctx = decl->getASTContext().BuiltinInfo;
+      return !ctx.isPredefinedLibFunction(builtin_id) &&
+             !ctx.isHeaderDependentFunction(builtin_id);
+    }
   }
   return false;
 }
