@@ -16,6 +16,7 @@
 // not hash_map: it's not as portable and needs hash<string>.
 #include <map>                          // for map, map<>::mapped_type, etc
 #include <memory>
+#include <regex>
 #include <string>                       // for string, basic_string, etc
 #include <system_error>                 // for error_code
 #include <utility>                      // for pair, make_pair
@@ -33,7 +34,6 @@
 #include "llvm/Support/ErrorOr.h"
 #include "llvm/Support/FileSystem.h"
 #include "llvm/Support/MemoryBuffer.h"
-#include "llvm/Support/Regex.h"
 #include "llvm/Support/SourceMgr.h"
 #include "llvm/Support/YAMLParser.h"
 #include "clang/Basic/FileManager.h"
@@ -89,19 +89,33 @@ const IncludeMapEntry libc_symbol_map[] = {
   // an option for this type.  That's the preferred #include all else
   // equal.  The visibility on the symbol-name is ignored; by convention
   // we always set it to kPrivate.
-  { "blksize_t", kPrivate, "<sys/types.h>", kPublic },
-  { "blkcnt_t", kPrivate, "<sys/stat.h>", kPublic },
+  { "aiocb", kPrivate, "<aio.h>", kPublic },
   { "blkcnt_t", kPrivate, "<sys/types.h>", kPublic },
+  { "blkcnt_t", kPrivate, "<sys/stat.h>", kPublic },
+  { "blksize_t", kPrivate, "<sys/types.h>", kPublic },
   { "blksize_t", kPrivate, "<sys/stat.h>", kPublic },
+  { "cc_t", kPrivate, "<termios.h>", kPublic },
   { "clock_t", kPrivate, "<sys/types.h>", kPublic },
+  { "clock_t", kPrivate, "<sys/time.h>", kPublic },
   { "clock_t", kPrivate, "<time.h>", kPublic },
+  { "clockid_t", kPrivate, "<sys/types.h>", kPublic },
+  { "clockid_t", kPrivate, "<time.h>", kPublic },
   { "daddr_t", kPrivate, "<sys/types.h>", kPublic },
   { "daddr_t", kPrivate, "<rpc/types.h>", kPublic },
   { "dev_t", kPrivate, "<sys/types.h>", kPublic },
   { "dev_t", kPrivate, "<sys/stat.h>", kPublic },
+  { "div_t", kPrivate, "<stdlib.h>", kPublic },
+  { "double_t", kPrivate, "<math.h>", kPublic },
   { "error_t", kPrivate, "<errno.h>", kPublic },
   { "error_t", kPrivate, "<argp.h>", kPublic },
   { "error_t", kPrivate, "<argz.h>", kPublic },
+  { "fd_set", kPrivate, "<sys/select.h>", kPublic },
+  { "fd_set", kPrivate, "<sys/time.h>", kPublic },
+  { "fenv_t", kPrivate, "<fenv.h>", kPublic },
+  { "fexcept_t", kPrivate, "<fenv.h>", kPublic },
+  { "FILE", kPrivate, "<stdio.h>", kPublic },
+  { "FILE", kPrivate, "<wchar.h>", kPublic },
+  { "float_t", kPrivate, "<math.h>", kPublic },
   { "fsblkcnt_t", kPrivate, "<sys/types.h>", kPublic },
   { "fsblkcnt_t", kPrivate, "<sys/statvfs.h>", kPublic },
   { "fsfilcnt_t", kPrivate, "<sys/types.h>", kPublic },
@@ -109,18 +123,21 @@ const IncludeMapEntry libc_symbol_map[] = {
   { "gid_t", kPrivate, "<sys/types.h>", kPublic },
   { "gid_t", kPrivate, "<grp.h>", kPublic },
   { "gid_t", kPrivate, "<pwd.h>", kPublic },
+  { "gid_t", kPrivate, "<signal.h>", kPublic },
   { "gid_t", kPrivate, "<stropts.h>", kPublic },
   { "gid_t", kPrivate, "<sys/ipc.h>", kPublic },
   { "gid_t", kPrivate, "<sys/stat.h>", kPublic },
   { "gid_t", kPrivate, "<unistd.h>", kPublic },
   { "id_t", kPrivate, "<sys/types.h>", kPublic },
   { "id_t", kPrivate, "<sys/resource.h>", kPublic },
+  { "imaxdiv_t", kPrivate, "<inttypes.h>", kPublic },
+  { "intmax_t", kPrivate, "<stdint.h>", kPublic },
+  { "uintmax_t", kPrivate, "<stdint.h>", kPublic },
   { "ino64_t", kPrivate, "<sys/types.h>", kPublic },
   { "ino64_t", kPrivate, "<dirent.h>", kPublic },
   { "ino_t", kPrivate, "<sys/types.h>", kPublic },
   { "ino_t", kPrivate, "<dirent.h>", kPublic },
   { "ino_t", kPrivate, "<sys/stat.h>", kPublic },
-  { "int8_t", kPrivate, "<sys/types.h>", kPublic },
   { "int8_t", kPrivate, "<stdint.h>", kPublic },
   { "int16_t", kPrivate, "<stdint.h>", kPublic },
   { "int32_t", kPrivate, "<stdint.h>", kPublic },
@@ -131,71 +148,140 @@ const IncludeMapEntry libc_symbol_map[] = {
   { "uint64_t", kPrivate, "<stdint.h>", kPublic },
   { "intptr_t", kPrivate, "<stdint.h>", kPublic },
   { "uintptr_t", kPrivate, "<stdint.h>", kPublic },
-  { "intptr_t", kPrivate, "<unistd.h>", kPublic },
   { "key_t", kPrivate, "<sys/types.h>", kPublic },
   { "key_t", kPrivate, "<sys/ipc.h>", kPublic },
+  { "lconv", kPrivate, "<locale.h>", kPublic },
+  { "ldiv_t", kPrivate, "<stdlib.h>", kPublic },
+  { "lldiv_t", kPrivate, "<stdlib.h>", kPublic },
   { "max_align_t", kPrivate, "<stddef.h>", kPublic },
   { "mode_t", kPrivate, "<sys/types.h>", kPublic },
-  { "mode_t", kPrivate, "<sys/stat.h>", kPublic },
+  { "mode_t", kPrivate, "<fcntl.h>", kPublic },
+  { "mode_t", kPrivate, "<ndbm.h>", kPublic },
+  { "mode_t", kPrivate, "<spawn.h>", kPublic },
   { "mode_t", kPrivate, "<sys/ipc.h>", kPublic },
   { "mode_t", kPrivate, "<sys/mman.h>", kPublic },
+  { "mode_t", kPrivate, "<sys/stat.h>", kPublic },
   { "nlink_t", kPrivate, "<sys/types.h>", kPublic },
   { "nlink_t", kPrivate, "<sys/stat.h>", kPublic },
   { "off64_t", kPrivate, "<sys/types.h>", kPublic },
   { "off64_t", kPrivate, "<unistd.h>", kPublic },
   { "off_t", kPrivate, "<sys/types.h>", kPublic },
-  { "off_t", kPrivate, "<unistd.h>", kPublic },
-  { "off_t", kPrivate, "<sys/stat.h>", kPublic },
+  { "off_t", kPrivate, "<aio.h>", kPublic },
+  { "off_t", kPrivate, "<fcntl.h>", kPublic },
+  { "off_t", kPrivate, "<stdio.h>", kPublic },
   { "off_t", kPrivate, "<sys/mman.h>", kPublic },
+  { "off_t", kPrivate, "<sys/stat.h>", kPublic },
+  { "off_t", kPrivate, "<unistd.h>", kPublic },
   { "pid_t", kPrivate, "<sys/types.h>", kPublic },
-  { "pid_t", kPrivate, "<unistd.h>", kPublic },
+  { "pid_t", kPrivate, "<fcntl.h>", kPublic },
+  { "pid_t", kPrivate, "<sched.h>", kPublic },
   { "pid_t", kPrivate, "<signal.h>", kPublic },
+  { "pid_t", kPrivate, "<spawn.h>", kPublic },
   { "pid_t", kPrivate, "<sys/msg.h>", kPublic },
+  { "pid_t", kPrivate, "<sys/sem.h>", kPublic },
   { "pid_t", kPrivate, "<sys/shm.h>", kPublic },
+  { "pid_t", kPrivate, "<sys/wait.h>", kPublic },
   { "pid_t", kPrivate, "<termios.h>", kPublic },
   { "pid_t", kPrivate, "<time.h>", kPublic },
+  { "pid_t", kPrivate, "<unistd.h>", kPublic },
   { "pid_t", kPrivate, "<utmpx.h>", kPublic },
   { "ptrdiff_t", kPrivate, "<stddef.h>", kPublic },
+  { "regex_t", kPrivate, "<regex.h>", kPublic },
+  { "regmatch_t", kPrivate, "<regex.h>", kPublic },
+  { "regoff_t", kPrivate, "<regex.h>", kPublic },
+  { "sigevent", kPrivate, "<signal.h>", kPublic },
+  { "sigevent", kPrivate, "<aio.h>", kPublic },
+  { "sigevent", kPrivate, "<mqueue.h>", kPublic },
+  { "sigevent", kPrivate, "<time.h>", kPublic },
+  { "siginfo_t", kPrivate, "<signal.h>", kPublic },
+  { "siginfo_t", kPrivate, "<sys/wait.h>", kPublic },
   { "sigset_t", kPrivate, "<signal.h>", kPublic },
-  { "sigset_t", kPrivate, "<sys/epoll.h>", kPublic },
+  { "sigset_t", kPrivate, "<spawn.h>", kPublic },
   { "sigset_t", kPrivate, "<sys/select.h>", kPublic },
-  { "socklen_t", kPrivate, "<bits/socket.h>", kPrivate },
-  { "socklen_t", kPrivate, "<unistd.h>", kPublic },
-  { "socklen_t", kPrivate, "<arpa/inet.h>", kPublic },
+  { "sigval", kPrivate, "<signal.h>", kPublic },
+  { "sockaddr", kPrivate, "<sys/socket.h>", kPublic },
+  { "socklen_t", kPrivate, "<sys/socket.h>", kPublic },
+  { "socklen_t", kPrivate, "<netdb.h>", kPublic },
   { "ssize_t", kPrivate, "<sys/types.h>", kPublic },
-  { "ssize_t", kPrivate, "<unistd.h>", kPublic },
+  { "ssize_t", kPrivate, "<aio.h>", kPublic },
   { "ssize_t", kPrivate, "<monetary.h>", kPublic },
+  { "ssize_t", kPrivate, "<mqueue.h>", kPublic },
+  { "ssize_t", kPrivate, "<stdio.h>", kPublic },
   { "ssize_t", kPrivate, "<sys/msg.h>", kPublic },
+  { "ssize_t", kPrivate, "<sys/socket.h>", kPublic },
+  { "ssize_t", kPrivate, "<sys/uio.h>", kPublic },
+  { "ssize_t", kPrivate, "<unistd.h>", kPublic },
+  { "stat", kPrivate, "<sys/stat.h>", kPublic },
+  { "stat", kPrivate, "<ftw.h>", kPublic },
   { "suseconds_t", kPrivate, "<sys/types.h>", kPublic },
-  { "suseconds_t", kPrivate, "<sys/time.h>", kPublic },
   { "suseconds_t", kPrivate, "<sys/select.h>", kPublic },
-  { "time_t", kPrivate, "<sys/types.h>", kPublic },
+  { "suseconds_t", kPrivate, "<sys/time.h>", kPublic },
   { "time_t", kPrivate, "<time.h>", kPublic },
+  { "time_t", kPrivate, "<sched.h>", kPublic },
+  { "time_t", kPrivate, "<sys/msg.h>", kPublic },
+  { "time_t", kPrivate, "<sys/select.h>", kPublic },
+  { "time_t", kPrivate, "<sys/sem.h>", kPublic },
+  { "time_t", kPrivate, "<sys/shm.h>", kPublic },
+  { "time_t", kPrivate, "<sys/stat.h>", kPublic },
+  { "time_t", kPrivate, "<sys/time.h>", kPublic },
+  { "time_t", kPrivate, "<sys/types.h>", kPublic },
+  { "time_t", kPrivate, "<utime.h>", kPublic },
+  { "timer_t", kPrivate, "<sys/types.h>", kPublic },
+  { "timer_t", kPrivate, "<time.h>", kPublic },
   { "timespec", kPrivate, "<time.h>", kPublic },
+  { "timespec", kPrivate, "<aio.h>", kPublic },
+  { "timespec", kPrivate, "<mqueue.h>", kPublic },
+  { "timespec", kPrivate, "<sched.h>", kPublic },
+  { "timespec", kPrivate, "<signal.h>", kPublic },
+  { "timespec", kPrivate, "<sys/select.h>", kPublic },
+  { "timespec", kPrivate, "<sys/stat.h>", kPublic },
   { "timeval", kPrivate, "<sys/time.h>", kPublic },
+  { "timeval", kPrivate, "<sys/resource.h>", kPublic },
+  { "timeval", kPrivate, "<sys/select.h>", kPublic },
+  { "timeval", kPrivate, "<utmpx.h>", kPublic },
   { "u_char", kPrivate, "<sys/types.h>", kPublic },
   { "u_char", kPrivate, "<rpc/types.h>", kPublic },
   { "uid_t", kPrivate, "<sys/types.h>", kPublic },
-  { "uid_t", kPrivate, "<unistd.h>", kPublic },
   { "uid_t", kPrivate, "<pwd.h>", kPublic },
   { "uid_t", kPrivate, "<signal.h>", kPublic },
   { "uid_t", kPrivate, "<stropts.h>", kPublic },
   { "uid_t", kPrivate, "<sys/ipc.h>", kPublic },
   { "uid_t", kPrivate, "<sys/stat.h>", kPublic },
+  { "uid_t", kPrivate, "<unistd.h>", kPublic },
   { "useconds_t", kPrivate, "<sys/types.h>", kPublic },
   { "useconds_t", kPrivate, "<unistd.h>", kPublic },
   { "wchar_t", kPrivate, "<stddef.h>", kPublic },
   { "wchar_t", kPrivate, "<stdlib.h>", kPublic },
-  // glob.h seems to define size_t if necessary, but it should come from stddef.
   // It is unspecified if the cname headers provide ::size_t.
   // <locale.h> is the one header which defines NULL but not size_t.
   { "size_t", kPrivate, "<stddef.h>", kPublic },  // 'canonical' location for size_t
+  { "size_t", kPrivate, "<aio.h>", kPublic },
+  { "size_t", kPrivate, "<glob.h>", kPublic },
+  { "size_t", kPrivate, "<grp.h>", kPublic },
+  { "size_t", kPrivate, "<iconv.h>", kPublic },
+  { "size_t", kPrivate, "<monetary.h>", kPublic },
+  { "size_t", kPrivate, "<mqueue.h>", kPublic },
+  { "size_t", kPrivate, "<ndbm.h>", kPublic },
+  { "size_t", kPrivate, "<pwd.h>", kPublic },
+  { "size_t", kPrivate, "<regex.h>", kPublic },
+  { "size_t", kPrivate, "<search.h>", kPublic },
+  { "size_t", kPrivate, "<signal.h>", kPublic },
   { "size_t", kPrivate, "<stdio.h>", kPublic },
   { "size_t", kPrivate, "<stdlib.h>", kPublic },
   { "size_t", kPrivate, "<string.h>", kPublic },
+  { "size_t", kPrivate, "<strings.h>", kPublic },
+  { "size_t", kPrivate, "<sys/mman.h>", kPublic },
+  { "size_t", kPrivate, "<sys/msg.h>", kPublic },
+  { "size_t", kPrivate, "<sys/sem.h>", kPublic },
+  { "size_t", kPrivate, "<sys/shm.h>", kPublic },
+  { "size_t", kPrivate, "<sys/socket.h>", kPublic },
+  { "size_t", kPrivate, "<sys/types.h>", kPublic },
+  { "size_t", kPrivate, "<sys/uio.h>", kPublic },
   { "size_t", kPrivate, "<time.h>", kPublic },
   { "size_t", kPrivate, "<uchar.h>", kPublic },
+  { "size_t", kPrivate, "<unistd.h>", kPublic },
   { "size_t", kPrivate, "<wchar.h>", kPublic },
+  { "size_t", kPrivate, "<wordexp.h>", kPublic },
   // Macros that can be defined in more than one file, don't have the
   // same __foo_defined guard that other types do, so the grep above
   // doesn't discover them.  Until I figure out a better way, I just
@@ -203,7 +289,13 @@ const IncludeMapEntry libc_symbol_map[] = {
   { "EOF", kPrivate, "<stdio.h>", kPublic },
   { "EOF", kPrivate, "<libio.h>", kPublic },
   { "FILE", kPrivate, "<stdio.h>", kPublic },
+  { "MAP_STACK", kPrivate, "<sys/mman.h>", kPublic },
+  { "MAP_STACK", kPrivate, "<linux/mman.h>", kPublic },
+  { "SIGCHLD", kPrivate, "<signal.h>", kPublic },
+  { "SIGCHLD", kPrivate, "<linux/signal.h>", kPublic },
   { "va_list", kPrivate, "<stdarg.h>", kPublic },
+  { "va_list", kPrivate, "<stdio.h>", kPublic },
+  { "va_list", kPrivate, "<wchar.h>", kPublic },
   // These are symbols that could be defined in either stdlib.h or
   // malloc.h, but we always want the stdlib location.
   { "malloc", kPrivate, "<stdlib.h>", kPublic },
@@ -252,10 +344,18 @@ const IncludeMapEntry libstdcpp_symbol_map[] = {
   { "std::char_traits", kPrivate, "<string>", kPublic },
   { "std::char_traits", kPrivate, "<ostream>", kPublic },
   { "std::char_traits", kPrivate, "<istream>", kPublic },
+
+  { "std::size_t", kPrivate, "<cstddef>", kPublic },  // 'canonical' location for std::size_t
+  { "std::size_t", kPrivate, "<cstdio>", kPublic },
+  { "std::size_t", kPrivate, "<cstdlib>", kPublic },
+  { "std::size_t", kPrivate, "<cstring>", kPublic },
+  { "std::size_t", kPrivate, "<ctime>", kPublic },
+  { "std::size_t", kPrivate, "<cuchar>", kPublic },
+  { "std::size_t", kPrivate, "<cwchar>", kPublic },
 };
 
-// Private -> public include mappings for GNU libc
 const IncludeMapEntry libc_include_map[] = {
+  // Private -> public include mappings for GNU libc
   // ( cd /usr/include && grep '^ *# *include' {sys/,net/,}* | perl -nle 'm/^([^:]+).*<([^>]+)>/ && print qq@    { "<$2>", kPrivate, "<$1>", kPublic },@' | grep bits/ | sort )
   // When I saw more than one mapping for these, I typically picked
   // what I thought was the "best" one.
@@ -459,6 +559,8 @@ const IncludeMapEntry libc_include_map[] = {
   { "<linux/limits.h>", kPrivate, "<limits.h>", kPublic },   // PATH_MAX
   { "<linux/prctl.h>", kPrivate, "<sys/prctl.h>", kPublic },
   { "<sys/ucontext.h>", kPrivate, "<ucontext.h>", kPublic },
+  // Exports guaranteed by the C standard
+  { "<stdint.h>", kPublic, "<inttypes.h>", kPublic },
 };
 
 const IncludeMapEntry stdlib_c_include_map[] = {
@@ -473,9 +575,10 @@ const IncludeMapEntry stdlib_c_include_map[] = {
   // mapping.)  Here is how I identified the files to map:
   // $ for i in /usr/include/c++/4.4/c* ; do ls /usr/include/`basename $i | cut -b2-`.h /usr/lib/gcc/*/4.4/include/`basename $i | cut -b2-`.h 2>/dev/null ; done
   //
-  // These headers are defined in C++14 [headers]p3.  You can get them with
-  // $ sed -n '/begin{floattable}.*{tab:cpp.c.headers}/,/end{floattable}/p' lib-intro.tex | grep tcode | perl -nle 'm/tcode{<c(.*)>}/ && print qq@  { "<$1.h>", kPublic, "<c$1>", kPublic },@' | sort
-  // on https://github.com/cplusplus/draft/blob/master/source/lib-intro.tex
+  // These headers are defined in [headers.cpp.c].
+  // https://github.com/cplusplus/draft/blob/c+%2B20/source/lib-intro.tex
+  //
+  // $ curl -s -N https://raw.githubusercontent.com/cplusplus/draft/c%2B%2B20/source/lib-intro.tex | sed -n '/begin{multicolfloattable}.*{headers.cpp.c}/,/end{multicolfloattable}/p' lib-intro.tex | grep tcode | perl -nle 'm/tcode{<c(.*)>}/ && print qq@  { "<$1.h>", kPublic, "<c$1>", kPublic },@' | sort
   { "<assert.h>", kPublic, "<cassert>", kPublic },
   { "<complex.h>", kPublic, "<ccomplex>", kPublic },
   { "<ctype.h>", kPublic, "<cctype>", kPublic },
@@ -505,19 +608,30 @@ const IncludeMapEntry stdlib_c_include_map[] = {
 };
 
 const char* stdlib_cpp_public_headers[] = {
-  // These headers are defined in C++14 [headers]p2.  You can get them with
-  // $ sed -n '/begin{floattable}.*{tab:cpp.library.headers}/,/end{floattable}/p' lib-intro.tex | grep tcode | perl -nle 'm/tcode{(.*)}/ && print qq@  "$1",@' | sort
-  // on https://github.com/cplusplus/draft/blob/master/source/lib-intro.tex
+  // These headers are defined in [headers.cpp].
+  // https://github.com/cplusplus/draft/blob/c+%2B20/source/lib-intro.tex
+  //
+  // $ curl -s -N https://raw.githubusercontent.com/cplusplus/draft/c%2B%2B20/source/lib-intro.tex | sed -n '/begin{multicolfloattable}.*{headers.cpp}/,/end{multicolfloattable}/p' lib-intro.tex | grep tcode | perl -nle 'm/tcode{(.*)}/ && print qq@  "$1",@' | sort
   "<algorithm>",
+  "<any>",
   "<array>",
   "<atomic>",
+  "<barrier>",
+  "<bit>",
   "<bitset>",
+  "<charconv>",
   "<chrono>",
   "<codecvt>",
+  "<compare>",
   "<complex>",
+  "<concepts>",
   "<condition_variable>",
+  "<coroutine>",
   "<deque>",
   "<exception>",
+  "<execution>",
+  "<filesystem>",
+  "<format>",
   "<forward_list>",
   "<fstream>",
   "<functional>",
@@ -529,43 +643,60 @@ const char* stdlib_cpp_public_headers[] = {
   "<iostream>",
   "<istream>",
   "<iterator>",
+  "<latch>",
   "<limits>",
   "<list>",
   "<locale>",
   "<map>",
   "<memory>",
+  "<memory_resource>",
   "<mutex>",
   "<new>",
+  "<numbers>",
   "<numeric>",
+  "<optional>",
   "<ostream>",
   "<queue>",
   "<random>",
+  "<ranges>",
   "<ratio>",
   "<regex>",
   "<scoped_allocator>",
+  "<semaphore>",
   "<set>",
+  "<shared_mutex>",
+  "<source_location>",
+  "<span>",
   "<sstream>",
   "<stack>",
   "<stdexcept>",
+  "<stop_token>",
   "<streambuf>",
   "<string>",
+  "<string_view>",
   "<strstream>",
+  "<syncstream>",
   "<system_error>",
   "<thread>",
   "<tuple>",
-  "<type_traits>",
   "<typeindex>",
   "<typeinfo>",
+  "<type_traits>",
   "<unordered_map>",
   "<unordered_set>",
   "<utility>",
   "<valarray>",
+  "<variant>",
   "<vector>",
+  "<version>",
 };
 
 // Private -> public include mappings for GNU libstdc++
+//
+// Note: make sure to sync this setting with gcc.stl.headers.imp
+//
 const IncludeMapEntry libstdcpp_include_map[] = {
-  // cd /usr/include/c++/8 && grep -r headername | perl -nle 'm/^([^:]+).*@headername\{([^,]*)\}/ && print qq@  { "<$1>", kPrivate, "<$2>", kPublic },@' | sort -u
+  // cd /usr/include/c++/10 && grep -r headername | perl -nle 'm/^([^:]+).*@headername\{([^,]*)\}/ && print qq@  { "<$1>", kPrivate, "<$2>", kPublic },@' | sort -u
   { "<backward/auto_ptr.h>", kPrivate, "<memory>", kPublic },
   { "<backward/backward_warning.h>", kPrivate, "<iosfwd>", kPublic },
   { "<backward/binders.h>", kPrivate, "<functional>", kPublic },
@@ -581,6 +712,7 @@ const IncludeMapEntry libstdcpp_include_map[] = {
   { "<bits/basic_string.tcc>", kPrivate, "<string>", kPublic },
   { "<bits/boost_concept_check.h>", kPrivate, "<iterator>", kPublic },
   { "<bits/c++0x_warning.h>", kPrivate, "<iosfwd>", kPublic },
+  { "<bits/charconv.h>", kPrivate, "<charconv>", kPublic },
   { "<bits/char_traits.h>", kPrivate, "<string>", kPublic },
   { "<bits/codecvt.h>", kPrivate, "<locale>", kPublic },
   { "<bits/concept_check.h>", kPrivate, "<iterator>", kPublic },
@@ -602,9 +734,11 @@ const IncludeMapEntry libstdcpp_include_map[] = {
   { "<bits/gslice.h>", kPrivate, "<valarray>", kPublic },
   { "<bits/hash_bytes.h>", kPrivate, "<functional>", kPublic },
   { "<bits/indirect_array.h>", kPrivate, "<valarray>", kPublic },
+  { "<bits/int_limits.h>", kPrivate, "<limits>", kPublic },
   { "<bits/invoke.h>", kPrivate, "<functional>", kPublic },
   { "<bits/ios_base.h>", kPrivate, "<ios>", kPublic },
   { "<bits/istream.tcc>", kPrivate, "<istream>", kPublic },
+  { "<bits/iterator_concepts.h>", kPrivate, "<iterator>", kPublic },
   { "<bits/list.tcc>", kPrivate, "<list>", kPublic },
   { "<bits/locale_classes.h>", kPrivate, "<locale>", kPublic },
   { "<bits/locale_classes.tcc>", kPrivate, "<locale>", kPublic },
@@ -628,6 +762,10 @@ const IncludeMapEntry libstdcpp_include_map[] = {
   { "<bits/random.h>", kPrivate, "<random>", kPublic },
   { "<bits/random.tcc>", kPrivate, "<random>", kPublic },
   { "<bits/range_access.h>", kPrivate, "<iterator>", kPublic },
+  { "<bits/range_cmp.h>", kPrivate, "<functional>", kPublic },
+  { "<bits/ranges_algobase.h>", kPrivate, "<algorithm>", kPublic },
+  { "<bits/ranges_algo.h>", kPrivate, "<algorithm>", kPublic },
+  { "<bits/ranges_uninitialized.h>", kPrivate, "<memory>", kPublic },
   { "<bits/refwrap.h>", kPrivate, "<functional>", kPublic },
   { "<bits/regex_automaton.h>", kPrivate, "<regex>", kPublic },
   { "<bits/regex_automaton.tcc>", kPrivate, "<regex>", kPublic },
@@ -679,6 +817,7 @@ const IncludeMapEntry libstdcpp_include_map[] = {
   { "<bits/stringfwd.h>", kPrivate, "<string>", kPublic },
   { "<bits/string_view.tcc>", kPrivate, "<string_view>", kPublic },
   { "<bits/uniform_int_dist.h>", kPrivate, "<random>", kPublic },
+  { "<bits/unique_lock.h>", kPrivate, "<mutex>", kPublic },
   { "<bits/unique_ptr.h>", kPrivate, "<memory>", kPublic },
   { "<bits/unordered_map.h>", kPrivate, "<unordered_map>", kPublic },
   { "<bits/unordered_set.h>", kPrivate, "<unordered_set>", kPublic },
@@ -692,6 +831,7 @@ const IncludeMapEntry libstdcpp_include_map[] = {
   { "<experimental/bits/fs_fwd.h>", kPrivate, "<experimental/filesystem>", kPublic },
   { "<experimental/bits/fs_ops.h>", kPrivate, "<experimental/filesystem>", kPublic },
   { "<experimental/bits/fs_path.h>", kPrivate, "<experimental/filesystem>", kPublic },
+  { "<experimental/bits/net.h>", kPrivate, "<experimental/net>", kPublic },
   { "<experimental/bits/shared_ptr.h>", kPrivate, "<experimental/memory>", kPublic },
   { "<experimental/bits/string_view.tcc>", kPrivate, "<experimental/string_view>", kPublic },
   { "<ext/cast.h>", kPrivate, "<ext/pointer.h>", kPublic },
@@ -721,10 +861,11 @@ const IncludeMapEntry libstdcpp_include_map[] = {
   { "<tr1/unordered_map.h>", kPrivate, "<tr1/unordered_map>", kPublic },
   { "<tr1/unordered_set.h>", kPrivate, "<tr1/unordered_set>", kPublic },
   { "<tr2/dynamic_bitset.tcc>", kPrivate, "<tr2/dynamic_bitset>", kPublic },
-  // cd /usr/include/x86_64-linux-gnu/c++/8 && grep -r headername | perl -nle 'm/^([^:]+).*@headername\{([^,]*)\}/ && print qq@  { "<$1>", kPrivate, "<$2>", kPublic },@' | sort -u
+  // cd /usr/include/x86_64-linux-gnu/c++/10 && grep -r headername | perl -nle 'm/^([^:]+).*@headername\{([^,]*)\}/ && print qq@  { "<$1>", kPrivate, "<$2>", kPublic },@' | sort -u
   { "<bits/basic_file.h>", kPrivate, "<ios>", kPublic },
   { "<bits/c++allocator.h>", kPrivate, "<memory>", kPublic },
   { "<bits/c++config.h>", kPrivate, "<iosfwd>", kPublic },
+  { "<bits/c++config.h>", kPrivate, "<version>", kPublic },
   { "<bits/c++io.h>", kPrivate, "<ios>", kPublic },
   { "<bits/c++locale.h>", kPrivate, "<locale>", kPublic },
   { "<bits/cpu_defines.h>", kPrivate, "<iosfwd>", kPublic },
@@ -865,6 +1006,14 @@ const IncludeMapEntry libstdcpp_include_map[] = {
   // The location of exception_defines.h varies by GCC version.  It should
   // never be included directly.
   { "<exception_defines.h>", kPrivate, "<exception>", kPublic },
+
+  // post libstdc++-10 stuff which is not automatically caught by commands above
+  { "<bits/exception.h>", kPrivate, "<exception>", kPublic },
+  { "<pstl/execution_defs.h>", kPrivate, "<execution>", kPublic },
+  { "<pstl/glue_algorithm_impl.h>", kPrivate, "<execution>", kPublic },
+  { "<pstl/glue_execution_defs.h>", kPrivate, "<execution>", kPublic },
+  { "<pstl/parallel_backend_tbb.h>", kPrivate, "<execution>", kPublic },
+  { "<tbb/tbb_stddef.h>", kPrivate, "<execution>", kPublic },
 };
 
 // Returns true if str is a valid quoted filepath pattern (i.e. either
@@ -1260,16 +1409,17 @@ void IncludePicker::ExpandRegexes() {
     for (const string& regex_key : filepath_include_map_regex_keys) {
       const vector<MappedInclude>& map_to = filepath_include_map_[regex_key];
       // Enclose the regex in ^(...)$ for full match.
-      llvm::Regex regex(std::string("^(" + regex_key.substr(1) + ")$"));
-      if (regex.match(hdr, nullptr) && !ContainsQuotedInclude(map_to, hdr)) {
+      std::regex regex(std::string("^(" + regex_key.substr(1) + ")$"));
+      if (std::regex_match(hdr, regex) &&
+          !ContainsQuotedInclude(map_to, hdr)) {
         Extend(&filepath_include_map_[hdr], filepath_include_map_[regex_key]);
         MarkVisibility(&include_visibility_map_, hdr,
                        include_visibility_map_[regex_key]);
       }
     }
     for (const string& regex_key : friend_to_headers_map_regex_keys) {
-      llvm::Regex regex(std::string("^(" + regex_key.substr(1) + ")$"));
-      if (regex.match(hdr, nullptr)) {
+      std::regex regex(std::string("^(" + regex_key.substr(1) + ")$"));
+      if (std::regex_match(hdr, regex)) {
         InsertAllInto(friend_to_headers_map_[regex_key],
                       &friend_to_headers_map_[hdr]);
       }
